/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#include <setjmp.h>
#include <dirent.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <time.h>
#include <unistd.h>
#include <stdio.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct tyTuple__euPCXX9bc3XzndEhYlqNS7g tyTuple__euPCXX9bc3XzndEhYlqNS7g;
typedef struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct RootObj RootObj;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA tyObject_Table__fdKWDDO1P17zvuQPReVgRA;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
typedef struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA;
typedef struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw tyObject_Table__IioUJGdqPI6xC7S7QF8MBw;
typedef struct tySequence__Qr6E8eH7btq79cFKGaJfGLw tySequence__Qr6E8eH7btq79cFKGaJfGLw;
typedef struct tyObject_Table__G1v8c16HePOldLeucwe05Q tyObject_Table__G1v8c16HePOldLeucwe05Q;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA;
typedef struct tySequence__23SMqauuRsbDANhthj9bWlA tySequence__23SMqauuRsbDANhthj9bWlA;
typedef struct tyObject_Table__NttoEzoiq5CiphZe81oadg tyObject_Table__NttoEzoiq5CiphZe81oadg;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg tyObject_Table__nagDFX4QHx0s6Fvma9blmSg;
typedef struct tySequence__pHNq3oXj9av2sEUdqaqeZjw tySequence__pHNq3oXj9av2sEUdqaqeZjw;
typedef struct tySequence__PzqTLBFNawCGiqTk0UORYw tySequence__PzqTLBFNawCGiqTk0UORYw;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw;
typedef struct tySequence__YdLNCDKYeipzJx3I8Xw82Q tySequence__YdLNCDKYeipzJx3I8Xw82Q;
typedef struct tySequence__PJMRIt5QxCm6bRaVyQ5CGA tySequence__PJMRIt5QxCm6bRaVyQ5CGA;
typedef struct tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ;
typedef struct tySequence__YWbgnI9b9a4j9aDYnupShIg3A tySequence__YWbgnI9b9a4j9aDYnupShIg3A;
typedef struct tyObject_Profiler__X5SfC6PDEhDFna4qLF0vtg tyObject_Profiler__X5SfC6PDEhDFna4qLF0vtg;
typedef struct tyObject_TStackFrame__DYXeymOyKb0OnIuD1ihEpQ tyObject_TStackFrame__DYXeymOyKb0OnIuD1ihEpQ;
typedef struct tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA;
typedef struct Exception Exception;
typedef struct tySequence__uB9b75OUPRENsBAu4AnoePA tySequence__uB9b75OUPRENsBAu4AnoePA;
typedef struct TSafePoint TSafePoint;
typedef struct tyObject_Time__3y2ZpqsTJLqdZvpC9a0rU2Q tyObject_Time__3y2ZpqsTJLqdZvpC9a0rU2Q;
typedef struct tyObject_TLLStream__a5oZYQ9aTktYME2449ayEi6g tyObject_TLLStream__a5oZYQ9aTktYME2449ayEi6g;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__quA39a2QdEQU9cSEIUSibApQ tyTuple__quA39a2QdEQU9cSEIUSibApQ;
typedef struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__wcNatyuf8WOqAhGLhSvgiw tyTuple__wcNatyuf8WOqAhGLhSvgiw;
typedef struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg;
typedef struct tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g;
typedef struct tyTuple__C1iPjdrPjiQaUrcFhIp9aGw tyTuple__C1iPjdrPjiQaUrcFhIp9aGw;
typedef struct tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA;
typedef struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA;

/* section: NIM_merge_TYPES */
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, tyProc__8ooe5vdoqmvpHnfXV29bP3w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__A7Sdoem70tRxSEmKrf9cmyg) (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__EAEKmBUgKFg29agoUGtzDEQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyTuple__euPCXX9bc3XzndEhYlqNS7g {
tyProc__8ooe5vdoqmvpHnfXV29bP3w Field0;
tyProc__A7Sdoem70tRxSEmKrf9cmyg Field1;
tyProc__EAEKmBUgKFg29agoUGtzDEQ Field2;
NIM_BOOL Field3;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__OLX364rHC66WkzRbMp49aQg[64];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__6GDJmNRiFxkWAAdMgUie8g[70];
struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA {
char dummy;
};
struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw {
tySequence__Qr6E8eH7btq79cFKGaJfGLw* data;
NI counter;
};
struct tyObject_Table__G1v8c16HePOldLeucwe05Q {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__c6vdo1yHyj19b9bS17tijS2w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__d5yEkT9aXkAtHvVerr7IeCQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(void, tyProc__sP1I7TbCn358eLy9bX4IphA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA {
tySequence__23SMqauuRsbDANhthj9bWlA* data;
NI counter;
};
struct tyObject_Table__NttoEzoiq5CiphZe81oadg {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg {
tySequence__pHNq3oXj9av2sEUdqaqeZjw* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3TeLOx1euAsRk3YCaQCuPg) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* modules;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA packageSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg deps;
tyObject_Table__fdKWDDO1P17zvuQPReVgRA importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* usageSym;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* owners;
tySequence__bWZXqEvLFwhLvAqSRoFNgQ* methods;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* systemModule;
tyArray__OLX364rHC66WkzRbMp49aQg sysTypes;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA compilerprocs;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA exposed;
tyArray__6GDJmNRiFxkWAAdMgUie8g intTypeCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA incr;
tyObject_Table__IioUJGdqPI6xC7S7QF8MBw canonTypes;
tyObject_Table__G1v8c16HePOldLeucwe05Q symBodyHashes;
tyProc__c6vdo1yHyj19b9bS17tijS2w importModuleCallback;
tyProc__d5yEkT9aXkAtHvVerr7IeCQ includeFileCallback;
tyProc__sP1I7TbCn358eLy9bX4IphA recordStmt;
tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA cacheSeqs;
tyObject_Table__NttoEzoiq5CiphZe81oadg cacheCounters;
tyObject_Table__nagDFX4QHx0s6Fvma9blmSg cacheTables;
tySequence__PzqTLBFNawCGiqTk0UORYw* passes;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinition;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinitionResolveForward;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onUsage;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* globalDestructors;
tyProc__sP1I7TbCn358eLy9bX4IphA strongSemCheck;
tyProc__3TeLOx1euAsRk3YCaQCuPg compatibleProps;
};
struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w {
  RootObj Sup;
};
typedef NU8 tyEnum_TEvalMode__UbrbHUpo4hYFr1DbYzJgRQ;
typedef NU8 tySet_tyEnum_TSandboxFlag__JyPEhkAmDAldmLHNNrLR0A;
struct tyObject_Profiler__X5SfC6PDEhDFna4qLF0vtg {
NF tEnter;
tyObject_TStackFrame__DYXeymOyKb0OnIuD1ihEpQ* tos;
};
struct tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw {
  tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w Sup;
tySequence__YdLNCDKYeipzJx3I8Xw82Q* code;
tySequence__PJMRIt5QxCm6bRaVyQ5CGA* debug;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* globals;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constants;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* types;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* currentExceptionA;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* currentExceptionB;
NI exceptionInstr;
tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ* prc;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* callsite;
tyEnum_TEvalMode__UbrbHUpo4hYFr1DbYzJgRQ mode;
tySet_tyEnum_TSandboxFlag__JyPEhkAmDAldmLHNNrLR0A features;
NIM_BOOL traceActive;
NI loopIterations;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q comesFromHeuristic;
tySequence__YWbgnI9b9a4j9aDYnupShIg3A* callbacks;
NimStringDesc* errorFlag;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph;
NI oldErrorCount;
tyObject_Profiler__X5SfC6PDEhDFna4qLF0vtg profiler;
NI* templInstCounter;
};
struct tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw {
  RootObj Sup;
NI colonstate_;
NimStringDesc* errorMsg1;
tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph2;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf3;
NimStringDesc* vthisDir4;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module5;
};
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* args, void* ClE_0);
void* ClE_0;
} tyProc__5QC9cKfPJmKuW0XbCTd8ylA;
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__uB9b75OUPRENsBAu4AnoePA* trace;
Exception* up;
};
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
typedef NU8 tySet_tyEnum_PathComponent__9c1SIU9cO1wHcl09b703A9cDrg;
typedef NU8 tyEnum_PathComponent__9c1SIU9cO1wHcl09b703A9cDrg;
typedef NIM_CHAR tyArray__dTlC27m9c9aWd5dvuePYanug[256];
struct tyObject_Time__3y2ZpqsTJLqdZvpC9a0rU2Q {
NI64 seconds;
NI nanosecond;
};
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_40) (tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* args, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_42) (tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* args, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_44) (tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* args, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_46) (tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* args, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_48) (tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* args, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_50) (tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* args, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_60) (tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* args, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_62) (tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* args, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_64) (tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* args, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_66) (tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* args, void* ClE_0);
typedef NU8 tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA;
typedef NU16 tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw;
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_78) (tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* args, void* ClE_0);
typedef NU8 tyEnum_FileMode__ZJfK20XeZ9bv2j1pZjw9aswg;
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyTuple__quA39a2QdEQU9cSEIUSibApQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg {
tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g* root;
NI entries;
};
struct tyTuple__wcNatyuf8WOqAhGLhSvgiw {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg Field2;
};
struct tyTuple__C1iPjdrPjiQaUrcFhIp9aGw {
NimStringDesc* Field0;
tyProc__5QC9cKfPJmKuW0XbCTd8ylA Field1;
};
struct tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA {
NI ra;
NI rb;
NI rc;
tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA* slots;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* currentException;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q currentLineInfo;
};
struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA {
NCSTRING procname;
NI line;
NCSTRING filename;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ {
  TGenericSeq Sup;
  tyTuple__quA39a2QdEQU9cSEIUSibApQ data[SEQ_DECL_SIZE];
};
struct tySequence__Qr6E8eH7btq79cFKGaJfGLw {
  TGenericSeq Sup;
  tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__23SMqauuRsbDANhthj9bWlA {
  TGenericSeq Sup;
  tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__pHNq3oXj9av2sEUdqaqeZjw {
  TGenericSeq Sup;
  tyTuple__wcNatyuf8WOqAhGLhSvgiw data[SEQ_DECL_SIZE];
};
struct tySequence__PzqTLBFNawCGiqTk0UORYw {
  TGenericSeq Sup;
  tyTuple__euPCXX9bc3XzndEhYlqNS7g data[SEQ_DECL_SIZE];
};
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__YdLNCDKYeipzJx3I8Xw82Q {
  TGenericSeq Sup;
  NU64 data[SEQ_DECL_SIZE];
};
struct tySequence__PJMRIt5QxCm6bRaVyQ5CGA {
  TGenericSeq Sup;
  tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q data[SEQ_DECL_SIZE];
};
struct tySequence__YWbgnI9b9a4j9aDYnupShIg3A {
  TGenericSeq Sup;
  tyTuple__C1iPjdrPjiQaUrcFhIp9aGw data[SEQ_DECL_SIZE];
};
struct tySequence__uB9b75OUPRENsBAu4AnoePA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ*, newModuleGraph__i9b4NK8jPhAUAsvbtMitNLw)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config);
N_LIB_PRIVATE N_NIMCALL(void, connectCallbacks__bgKSaiGTRW4vbGh2XuGqSw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph);
N_LIB_PRIVATE N_NIMCALL(void, initDefines__hODM2As3BZvC4AAFuVvWwQ)(tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols);
N_LIB_PRIVATE N_NIMCALL(void, defineSymbol__znuJizGq3isbcihOOtUY0A)(tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols, NimStringDesc* symbol, NimStringDesc* value);
N_LIB_PRIVATE N_NIMCALL(void, registerPass__VbG3eW9b2jtFMJI9bafKW9aRw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyTuple__euPCXX9bc3XzndEhYlqNS7g* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, myOpen__aOG8hV039bfSL2VAm1lrf0Q)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, myProcess__QAJdPOwMq9buTNGNGQO3ImA)(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* context, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, myClose__q2jGmbBjsPumxfsrswciWg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* context, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, myOpen__4vajIPhcf9a5bJvp6m9ciz6A)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, myProcess__Owg2e1qJ9cqcKRBQZVvmIWg)(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, myClose__9cMiASXBM9bgOmq0622U8U0g)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(void, undefSymbol__7r39cyzHGkKGsFt9bPVES2hQ)(tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols, NimStringDesc* symbol);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, makeModule__X0YNzSZYcyX9cz31YOsPZuA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw*, setupVM__ykATGWoPQlrTWSpzeaqsuA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, NimStringDesc* scriptName, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tyRef__09cLp9cIksPJn1aayfzodABg)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw*, newCtx__SnMRNFK9aeDXTXGWpZkzETw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(void, registerAdditionalOps__YCoJV0XHfn0P9cfljlakO1g)(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw* c);
N_LIB_PRIVATE N_NIMCALL(void, nossplitFile)(NimStringDesc* path, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(NI, registerCallback__KnNoqgKj9bmG2p3f4SLNFqA)(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw* c, NimStringDesc* name, tyProc__5QC9cKfPJmKuW0XbCTd8ylA callback);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
N_LIB_PRIVATE N_NIMCALL(void, listDirs__RprYzeqk3Kgtg5VI9b4jWvQ)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, tySet_tyEnum_PathComponent__9c1SIU9cO1wHcl09b703A9cDrg filter);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getString__fqypzXhNY5rpF89ak7Q0GlQ)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, NI i);
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s);
N_LIB_PRIVATE N_NOINLINE(void, raiseOSError__CWyPYlyH9a6rAuZckFyVxPA)(NI32 errorCode, NimStringDesc* additionalInfo);
N_LIB_PRIVATE N_NIMCALL(NI32, osLastError__9bUWNxbcGnToMWA9b79aTXLIw)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, cstrToNimstr)(NCSTRING str);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, slash___gEyhbzZ1UcxyenWRLJRXNQ)(NimStringDesc* head, NimStringDesc* tail);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosdirExists)(NimStringDesc* dir);
N_LIB_PRIVATE N_NIMCALL(tyEnum_PathComponent__9c1SIU9cO1wHcl09b703A9cDrg, getSymlinkFileKind__wTnLPNAWjgwVnuiJ9ax0ZGQ)(NimStringDesc* path);
static N_INLINE(void, popSafePoint)(void);
N_LIB_PRIVATE N_NIMCALL(void, nimLeaveFinally)(void);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
N_LIB_PRIVATE N_NIMCALL(void, setResult__nH0psxYZ8gVURA1upHNltw)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, tySequence__sM4lkSb7zS6F7OVMvW9cffQ* v);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isObj)(TNimType* obj, TNimType* subclass);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(NimStringDesc*, getCurrentExceptionMsg__jLt3ACHcgYt9bbV4Vf9a5mgwsystem)(void);
static N_INLINE(void, popCurrentException)(void);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_2)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_3)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, nosremoveDir)(NimStringDesc* dir, NIM_BOOL checkDir);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, getBool__EhqFCFCIHmFhBfWH28wGww)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, NI i);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_4)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, nosremoveFile)(NimStringDesc* file);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_5)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, noscreateDir)(NimStringDesc* dir);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_6)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, setResult__g9crT9ba9c0OxETalTxR9cv1Sw)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, NimStringDesc* v);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_7)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
static N_INLINE(void, setCurrentDir__gH49bWY7pApxazoTIU6NIpwos)(NimStringDesc* newDir);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_8)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosgetCurrentDir)(void);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_9)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, nosmoveFile)(NimStringDesc* source, NimStringDesc* dest);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_10)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, moveDir__ZIkDlvIsvzKWHk1wL9bH1lg)(NimStringDesc* source, NimStringDesc* dest);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_11)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, noscopyFile)(NimStringDesc* source, NimStringDesc* dest);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_12)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, noscopyDir)(NimStringDesc* source, NimStringDesc* dest);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_13)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, setResult__TT9cdDQkh09c214lMSxKXTTg)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, NI64 v);
N_LIB_PRIVATE N_NIMCALL(NI64, toUnix__mXmxlr1pBpariZiJTjytHg)(tyObject_Time__3y2ZpqsTJLqdZvpC9a0rU2Q t);
N_LIB_PRIVATE N_NIMCALL(tyObject_Time__3y2ZpqsTJLqdZvpC9a0rU2Q, nosgetLastModificationTime)(NimStringDesc* file);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_14)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, findExe__9cov9c3aI19bfbEIyMe9bNCSEA)(NimStringDesc* exe, NIM_BOOL followSymlinks, NimStringDesc** extensions, NI extensionsLen_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_15)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NI, nospexecCmd)(NimStringDesc* command);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getEnv__hhED57tMl0Iaa5bOg9cJaig)(NimStringDesc* key, NimStringDesc* default_0);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_2)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a);
N_LIB_PRIVATE N_NIMCALL(void, setResult__X7b1uTvNjENZoIKwHxPn9aA)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, NIM_BOOL v);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, existsEnv__HhiDHRQxJ349a6FFxO51gqQ)(NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_3)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a);
N_LIB_PRIVATE N_NIMCALL(void, putEnv__YVZCqlK3fKyVR367JpYgKA)(NimStringDesc* key, NimStringDesc* val);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_4)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a);
N_LIB_PRIVATE N_NIMCALL(void, delEnv__B4Cfq0UpEu7Wu9cYZh9cgVlw)(NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_5)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_6)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileExists)(NimStringDesc* filename);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_16)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_17)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_18)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_19)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_20)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, setConfigVar__6QeR1iJ9b9aIgKE4A0vKaYTQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* key, NimStringDesc* val);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_21)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getConfigVar__nT6pi8CimjduqrsM6Cc8mQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* key, NimStringDesc* default_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_22)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, existsConfigVar__ut8y6zhxwL6n6Sz9akfQBGg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* key);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_23)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getNimcacheDir__oltK69akg0xLqkR2ITKbomg_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_7)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, paramStr__T0ST6UXXTEqaiXY9akIayng)(NI i);
N_LIB_PRIVATE N_NIMCALL(NI64, getInt__VJ5Unk9bDoOAoLiZLdhb9b1Q)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, NI i);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_8)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a);
N_LIB_PRIVATE N_NIMCALL(NI, paramCount__LYkRnwMk6UXTCs9c59cPvZsQ)(void);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_9)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_10)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreCase)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_24)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosisAbsolute)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, slash___QVqo5OOQAdrjFqBsPctklw)(NimStringDesc* base, NimStringDesc* f);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, canonicalizePath__9bhgFqdEZM7DoX7p3U69bQEg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* path);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_25)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_26)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, processSwitch__DS57z9bPOnpy1Lyf6Fyb2vA)(NimStringDesc* switch_0, NimStringDesc* arg, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_27)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, processSpecificNote__B59avMINa9cm5CFqefE9bgZIQ)(NimStringDesc* arg, tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw state, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* orig, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_28)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_29)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosaddFileExt)(NimStringDesc* filename, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__wAzSnEu9cCHHjvPQlWBZUeQ)(NimStringDesc* s, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, pathSubs__paMedXIWX6si307wASTsQQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* p, NimStringDesc* config);
N_LIB_PRIVATE N_NIMCALL(void, nstPut)(tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* t, NimStringDesc* key, NimStringDesc* val);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_11)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosgetAppFilename)(void);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_30)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, cppDefine__3wmoYTSOyQ3GsJJ4H7J3lQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* c, NimStringDesc* define);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_31)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, readLine__IfmAdseskhTUnfEYpOo5fA)(FILE* f);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_32)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, readAll__mQf9blHFlTwuSvJjirhpY6g)(FILE* file);
N_LIB_PRIVATE N_NIMCALL(void, compileSystemModule__bgKSaiGTRW4vbGh2XuGqSw_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, processModule__zPTa50e0M05UK8aJ9bS48aw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_TLLStream__a5oZYQ9aTktYME2449ayEi6g* stream);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLLStream__a5oZYQ9aTktYME2449ayEi6g*, llStreamOpen__knWUQJsEzojha6AJCi6LcA)(NimStringDesc* filename, tyEnum_FileMode__ZJfK20XeZ9bv2j1pZjw9aswg mode);
N_LIB_PRIVATE N_NIMCALL(void, resetSystemArtifacts__qtJqiNk9aIOJrZ429bKn9aGZw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);

/* section: NIM_merge_DATA */
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_2, "nimscript", 9);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_3, "true", 4);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_4, "nimconfig", 9);
extern TNimType NTI__sM4lkSb7zS6F7OVMvW9cffQ_;
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_5, "nimv2", 5);
extern TNimType NTI__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTI__OuG3LnpRCpfRkLDW5KdmIw_;
extern TNimType NTI__xHTZrq9aYs6boc9bCba0JbpQ_;
extern TNimType NTI__77mFvmsOLKik79ci2hXkHEg_;
extern TNimType NTI__KfdHSsl8vyUCSI9b3inBcww_;
extern TNimType NTI__a8lycfSA25OQltN3OMeBsA_;
extern TNimType NTI__K9bspPztfoWajecnwjyHuYQ_;
N_LIB_PRIVATE TNimType NTI__09cLp9cIksPJn1aayfzodABg_;
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_7, "stdlib.system.listFilesImpl", 27);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_10, ".", 1);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_11, "..", 2);
extern TNimType NTI__BeJgrOdDsczOwEWOZbRfKA_;
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_12, "stdlib.system.listDirsImpl", 26);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_14, "stdlib.system.removeDir", 23);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_16, "stdlib.system.removeFile", 24);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_18, "stdlib.system.createDir", 23);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_20, "stdlib.system.getError", 22);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_21, "stdlib.system.setCurrentDir", 27);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_23, "stdlib.system.getCurrentDir", 27);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_25, "stdlib.system.moveFile", 22);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_27, "stdlib.system.moveDir", 21);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_29, "stdlib.system.copyFile", 22);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_31, "stdlib.system.copyDir", 21);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_33, "stdlib.system.getLastModificationTime", 37);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_35, "stdlib.system.findExe", 21);
extern NIM_CONST tyArray__nHXaesL0DJZHyVS07ARPRA ExeExts__ONrgkgAZ9bh6KVTWl4XeOSw;
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_37, "stdlib.system.rawExec", 21);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_39, "stdlib.system.getEnv", 20);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_41, "stdlib.system.existsEnv", 23);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_43, "stdlib.system.putEnv", 20);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_45, "stdlib.system.delEnv", 20);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_47, "stdlib.system.dirExists", 23);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_49, "stdlib.system.fileExists", 24);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_51, "stdlib.system.projectName", 25);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_52, "stdlib.system.projectDir", 24);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_53, "stdlib.system.projectPath", 25);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_54, "stdlib.system.thisDir", 21);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_55, "stdlib.system.put", 17);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_56, "stdlib.system.get", 17);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_57, "stdlib.system.exists", 20);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_58, "stdlib.system.nimcacheDir", 25);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_59, "stdlib.system.paramStr", 22);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_61, "stdlib.system.paramCount", 24);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_63, "stdlib.system.cmpIgnoreStyle", 28);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_65, "stdlib.system.cmpIgnoreCase", 27);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_67, "stdlib.system.setCommand", 24);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_69, "stdlib.system.getCommand", 24);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_70, "stdlib.system.switch", 20);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_71, "stdlib.system.hintImpl", 22);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_72, "stdlib.system.warningImpl", 25);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_73, "stdlib.system.patchFile", 23);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_74, "_", 1);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_75, "nim", 3);
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__FA6jNt3IW9afkuZFmR0bnUQ_76 = {
0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_77, "stdlib.system.selfExe", 21);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_79, "stdlib.system.cppDefine", 23);
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_80, "stdlib.system.stdinReadLine", 27);
extern TNimType NTI__KGSY1JdrNB7Xi8KDhXFhSg_;
STRING_LITERAL(TM__FA6jNt3IW9afkuZFmR0bnUQ_82, "stdlib.system.stdinReadAll", 26);

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;

/* section: NIM_merge_PROCS */
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
static N_NIMCALL(void, Marker_tyRef__09cLp9cIksPJn1aayfzodABg)(void* p, NI op) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* a;
	a = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*)p;
	nimGCvisit((void*)(*a).errorMsg1, op);
	nimGCvisit((void*)(*a).graph2, op);
	nimGCvisit((void*)(*a).conf3, op);
	nimGCvisit((void*)(*a).vthisDir4, op);
	nimGCvisit((void*)(*a).module5, op);
}
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory(p, ((int) 0), size);
}
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__rqLlY5bs9atDw2OXYqJEn5g;
	excHandler__rqLlY5bs9atDw2OXYqJEn5g = s;
}
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s) {
	NCSTRING result;
	result = (NCSTRING)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (s == ((NimStringDesc*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = ((*s).Sup.len == ((NI) 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = "";
	}
	goto LA1_;
	LA5_: ;
	{
		result = ((NCSTRING) ((*s).data));
	}
	LA1_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__rqLlY5bs9atDw2OXYqJEn5g = (*excHandler__rqLlY5bs9atDw2OXYqJEn5g).prev;
}
N_LIB_PRIVATE N_NIMCALL(void, listDirs__RprYzeqk3Kgtg5VI9b4jWvQ)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, tySet_tyEnum_PathComponent__9c1SIU9cO1wHcl09b703A9cDrg filter) {
	NimStringDesc* dir;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* result;
	dir = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
	result = NIM_NIL;
	{
		tyEnum_PathComponent__9c1SIU9cO1wHcl09b703A9cDrg kind;
		NimStringDesc* path;
		DIR* d;
		kind = (tyEnum_PathComponent__9c1SIU9cO1wHcl09b703A9cDrg)0;
		path = (NimStringDesc*)0;
		d = opendir(nimToCStringConv(dir));
		{
			if (!(d == ((DIR*) NIM_NIL))) goto LA4_;
			{
				NI32 T10_;
				if (!NIM_FALSE) goto LA8_;
				T10_ = (NI32)0;
				T10_ = osLastError__9bUWNxbcGnToMWA9b79aTXLIw();
				raiseOSError__CWyPYlyH9a6rAuZckFyVxPA(T10_, dir);
			}
			LA8_: ;
		}
		goto LA2_;
		LA4_: ;
		{
			TSafePoint TM__FA6jNt3IW9afkuZFmR0bnUQ_9;
			pushSafePoint(&TM__FA6jNt3IW9afkuZFmR0bnUQ_9);
			TM__FA6jNt3IW9afkuZFmR0bnUQ_9.status = _setjmp(TM__FA6jNt3IW9afkuZFmR0bnUQ_9.context);
			if (TM__FA6jNt3IW9afkuZFmR0bnUQ_9.status == 0) {
			{
				while (1) {
					{
						struct dirent* x;
						NimStringDesc* y;
						x = readdir(d);
						{
							if (!(x == ((struct dirent*) NIM_NIL))) goto LA17_;
							goto LA12;
						}
						LA17_: ;
						y = cstrToNimstr(((NCSTRING) ((*x).d_name)));
						{
							NIM_BOOL T21_;
							struct stat s;
							NimStringDesc* path_2;
							tyEnum_PathComponent__9c1SIU9cO1wHcl09b703A9cDrg k;
							T21_ = (NIM_BOOL)0;
							T21_ = !(eqStrings(y, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_10)));
							if (!(T21_)) goto LA22_;
							T21_ = !(eqStrings(y, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_11)));
							LA22_: ;
							if (!T21_) goto LA23_;
							nimZeroMem((void*)(&s), sizeof(struct stat));
							path_2 = slash___gEyhbzZ1UcxyenWRLJRXNQ(dir, y);
							{
								if (!NIM_TRUE) goto LA27_;
								y = copyString(path_2);
							}
							LA27_: ;
							k = ((tyEnum_PathComponent__9c1SIU9cO1wHcl09b703A9cDrg) 0);
							{
								if (!!(((*x).d_type == ((NI8) 0)))) goto LA31_;
								{
									if (!((*x).d_type == ((NI8) 4))) goto LA35_;
									k = ((tyEnum_PathComponent__9c1SIU9cO1wHcl09b703A9cDrg) 2);
								}
								LA35_: ;
								{
									if (!((*x).d_type == ((NI8) 10))) goto LA39_;
									{
										NIM_BOOL T43_;
										T43_ = (NIM_BOOL)0;
										T43_ = nosdirExists(path_2);
										if (!T43_) goto LA44_;
										k = ((tyEnum_PathComponent__9c1SIU9cO1wHcl09b703A9cDrg) 3);
									}
									goto LA41_;
									LA44_: ;
									{
										k = ((tyEnum_PathComponent__9c1SIU9cO1wHcl09b703A9cDrg) 1);
									}
									LA41_: ;
								}
								LA39_: ;
								kind = k;
								path = y;
								{
									NI T51_;
									NimStringDesc* T52_;
									if (!((filter &((NU8)1<<((NU)(kind)&7U)))!=0)) goto LA49_;
									result = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)(result), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_));
									T51_ = result->Sup.len++;
									T52_ = (NimStringDesc*)0;
									T52_ = result->data[T51_]; result->data[T51_] = copyStringRC1(path);
									if (T52_) nimGCunrefNoCycle(T52_);
								}
								LA49_: ;
								goto LA14;
							}
							LA31_: ;
							{
								int T55_;
								T55_ = (int)0;
								T55_ = lstat(nimToCStringConv(path_2), (&s));
								if (!(T55_ < ((NI32) 0))) goto LA56_;
								goto LA12;
							}
							LA56_: ;
							{
								NIM_BOOL T60_;
								T60_ = (NIM_BOOL)0;
								T60_ = S_ISDIR(s.st_mode);
								if (!T60_) goto LA61_;
								k = ((tyEnum_PathComponent__9c1SIU9cO1wHcl09b703A9cDrg) 2);
							}
							goto LA58_;
							LA61_: ;
							{
								NIM_BOOL T64_;
								T64_ = (NIM_BOOL)0;
								T64_ = S_ISLNK(s.st_mode);
								if (!T64_) goto LA65_;
								k = getSymlinkFileKind__wTnLPNAWjgwVnuiJ9ax0ZGQ(path_2);
							}
							goto LA58_;
							LA65_: ;
							LA58_: ;
							kind = k;
							path = y;
							{
								NI T71_;
								NimStringDesc* T72_;
								if (!((filter &((NU8)1<<((NU)(kind)&7U)))!=0)) goto LA69_;
								result = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)(result), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_));
								T71_ = result->Sup.len++;
								T72_ = (NimStringDesc*)0;
								T72_ = result->data[T71_]; result->data[T71_] = copyStringRC1(path);
								if (T72_) nimGCunrefNoCycle(T72_);
							}
							LA69_: ;
						}
						LA23_: ;
					} LA14: ;
				}
			} LA12: ;
			popSafePoint();
			}
			else {
				popSafePoint();
			}
			{
				int T75_;
				T75_ = (int)0;
				T75_ = closedir(d);
				(void)(T75_);
				if (TM__FA6jNt3IW9afkuZFmR0bnUQ_9.status != 0) nimLeaveFinally();
			}
			if (TM__FA6jNt3IW9afkuZFmR0bnUQ_9.status != 0) reraiseException();
		}
		LA2_: ;
	}
	setResult__nH0psxYZ8gVURA1upHNltw(a, result);
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = (Exception*)0;
	result = currException__9bVPeDJlYTi9bQApZpfH8wjg;
	return result;
}
static N_INLINE(NimStringDesc*, getCurrentExceptionMsg__jLt3ACHcgYt9bbV4Vf9a5mgwsystem)(void) {
	NimStringDesc* result;
{	result = (NimStringDesc*)0;
	{
		if (!(currException__9bVPeDJlYTi9bQApZpfH8wjg == ((Exception*) NIM_NIL))) goto LA3_;
		result = ((NimStringDesc*) NIM_NIL);
	}
	goto LA1_;
	LA3_: ;
	{
		result = copyString((*currException__9bVPeDJlYTi9bQApZpfH8wjg).message);
	}
	LA1_: ;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	asgnRef((void**) (&currException__9bVPeDJlYTi9bQApZpfH8wjg), (*currException__9bVPeDJlYTi9bQApZpfH8wjg).up);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	TSafePoint TM__FA6jNt3IW9afkuZFmR0bnUQ_8;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__FA6jNt3IW9afkuZFmR0bnUQ_8);
	TM__FA6jNt3IW9afkuZFmR0bnUQ_8.status = _setjmp(TM__FA6jNt3IW9afkuZFmR0bnUQ_8.context);
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_8.status == 0) {
	listDirs__RprYzeqk3Kgtg5VI9b4jWvQ(a, 3);
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__BeJgrOdDsczOwEWOZbRfKA_))) {
			TM__FA6jNt3IW9afkuZFmR0bnUQ_8.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__jLt3ACHcgYt9bbV4Vf9a5mgwsystem());
			popCurrentException();
		}
	}
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_8.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_2)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	TSafePoint TM__FA6jNt3IW9afkuZFmR0bnUQ_13;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__FA6jNt3IW9afkuZFmR0bnUQ_13);
	TM__FA6jNt3IW9afkuZFmR0bnUQ_13.status = _setjmp(TM__FA6jNt3IW9afkuZFmR0bnUQ_13.context);
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_13.status == 0) {
	listDirs__RprYzeqk3Kgtg5VI9b4jWvQ(a, 4);
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__BeJgrOdDsczOwEWOZbRfKA_))) {
			TM__FA6jNt3IW9afkuZFmR0bnUQ_13.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__jLt3ACHcgYt9bbV4Vf9a5mgwsystem());
			popCurrentException();
		}
	}
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_13.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_3)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	TSafePoint TM__FA6jNt3IW9afkuZFmR0bnUQ_15;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__FA6jNt3IW9afkuZFmR0bnUQ_15);
	TM__FA6jNt3IW9afkuZFmR0bnUQ_15.status = _setjmp(TM__FA6jNt3IW9afkuZFmR0bnUQ_15.context);
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_15.status == 0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = NIM_FALSE;
		if (T3_) goto LA4_;
		T3_ = ((*(*(*colonenvP_).graph2).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 11));
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T8_;
		NIM_BOOL T9_;
		T8_ = (NimStringDesc*)0;
		T8_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
		T9_ = (NIM_BOOL)0;
		T9_ = getBool__EhqFCFCIHmFhBfWH28wGww(a, ((NI) 1));
		nosremoveDir(T8_, T9_);
	}
	LA1_: ;
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__BeJgrOdDsczOwEWOZbRfKA_))) {
			TM__FA6jNt3IW9afkuZFmR0bnUQ_15.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__jLt3ACHcgYt9bbV4Vf9a5mgwsystem());
			popCurrentException();
		}
	}
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_15.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_4)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	TSafePoint TM__FA6jNt3IW9afkuZFmR0bnUQ_17;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__FA6jNt3IW9afkuZFmR0bnUQ_17);
	TM__FA6jNt3IW9afkuZFmR0bnUQ_17.status = _setjmp(TM__FA6jNt3IW9afkuZFmR0bnUQ_17.context);
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_17.status == 0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = NIM_FALSE;
		if (T3_) goto LA4_;
		T3_ = ((*(*(*colonenvP_).graph2).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 11));
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T8_;
		T8_ = (NimStringDesc*)0;
		T8_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
		nosremoveFile(T8_);
	}
	LA1_: ;
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__BeJgrOdDsczOwEWOZbRfKA_))) {
			TM__FA6jNt3IW9afkuZFmR0bnUQ_17.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__jLt3ACHcgYt9bbV4Vf9a5mgwsystem());
			popCurrentException();
		}
	}
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_17.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_5)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	TSafePoint TM__FA6jNt3IW9afkuZFmR0bnUQ_19;
	NimStringDesc* T1_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__FA6jNt3IW9afkuZFmR0bnUQ_19);
	TM__FA6jNt3IW9afkuZFmR0bnUQ_19.status = _setjmp(TM__FA6jNt3IW9afkuZFmR0bnUQ_19.context);
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_19.status == 0) {
	T1_ = (NimStringDesc*)0;
	T1_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
	noscreateDir(T1_);
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__BeJgrOdDsczOwEWOZbRfKA_))) {
			TM__FA6jNt3IW9afkuZFmR0bnUQ_19.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__jLt3ACHcgYt9bbV4Vf9a5mgwsystem());
			popCurrentException();
		}
	}
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_19.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_6)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	setResult__g9crT9ba9c0OxETalTxR9cv1Sw(a, (*colonenvP_).errorMsg1);
}
static N_INLINE(void, setCurrentDir__gH49bWY7pApxazoTIU6NIpwos)(NimStringDesc* newDir) {
	{
		int T3_;
		NI32 T6_;
		T3_ = (int)0;
		T3_ = chdir(nimToCStringConv(newDir));
		if (!!((T3_ == ((NI32) 0)))) goto LA4_;
		T6_ = (NI32)0;
		T6_ = osLastError__9bUWNxbcGnToMWA9b79aTXLIw();
		raiseOSError__CWyPYlyH9a6rAuZckFyVxPA(T6_, newDir);
	}
	LA4_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_7)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	TSafePoint TM__FA6jNt3IW9afkuZFmR0bnUQ_22;
	NimStringDesc* T1_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__FA6jNt3IW9afkuZFmR0bnUQ_22);
	TM__FA6jNt3IW9afkuZFmR0bnUQ_22.status = _setjmp(TM__FA6jNt3IW9afkuZFmR0bnUQ_22.context);
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_22.status == 0) {
	T1_ = (NimStringDesc*)0;
	T1_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
	setCurrentDir__gH49bWY7pApxazoTIU6NIpwos(T1_);
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__BeJgrOdDsczOwEWOZbRfKA_))) {
			TM__FA6jNt3IW9afkuZFmR0bnUQ_22.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__jLt3ACHcgYt9bbV4Vf9a5mgwsystem());
			popCurrentException();
		}
	}
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_22.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_8)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	TSafePoint TM__FA6jNt3IW9afkuZFmR0bnUQ_24;
	NimStringDesc* T1_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__FA6jNt3IW9afkuZFmR0bnUQ_24);
	TM__FA6jNt3IW9afkuZFmR0bnUQ_24.status = _setjmp(TM__FA6jNt3IW9afkuZFmR0bnUQ_24.context);
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_24.status == 0) {
	T1_ = (NimStringDesc*)0;
	T1_ = nosgetCurrentDir();
	setResult__g9crT9ba9c0OxETalTxR9cv1Sw(a, T1_);
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__BeJgrOdDsczOwEWOZbRfKA_))) {
			TM__FA6jNt3IW9afkuZFmR0bnUQ_24.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__jLt3ACHcgYt9bbV4Vf9a5mgwsystem());
			popCurrentException();
		}
	}
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_24.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_9)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	TSafePoint TM__FA6jNt3IW9afkuZFmR0bnUQ_26;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__FA6jNt3IW9afkuZFmR0bnUQ_26);
	TM__FA6jNt3IW9afkuZFmR0bnUQ_26.status = _setjmp(TM__FA6jNt3IW9afkuZFmR0bnUQ_26.context);
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_26.status == 0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = NIM_FALSE;
		if (T3_) goto LA4_;
		T3_ = ((*(*(*colonenvP_).graph2).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 11));
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T8_;
		NimStringDesc* T9_;
		T8_ = (NimStringDesc*)0;
		T8_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
		T9_ = (NimStringDesc*)0;
		T9_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 1));
		nosmoveFile(T8_, T9_);
	}
	LA1_: ;
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__BeJgrOdDsczOwEWOZbRfKA_))) {
			TM__FA6jNt3IW9afkuZFmR0bnUQ_26.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__jLt3ACHcgYt9bbV4Vf9a5mgwsystem());
			popCurrentException();
		}
	}
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_26.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_10)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	TSafePoint TM__FA6jNt3IW9afkuZFmR0bnUQ_28;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__FA6jNt3IW9afkuZFmR0bnUQ_28);
	TM__FA6jNt3IW9afkuZFmR0bnUQ_28.status = _setjmp(TM__FA6jNt3IW9afkuZFmR0bnUQ_28.context);
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_28.status == 0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = NIM_FALSE;
		if (T3_) goto LA4_;
		T3_ = ((*(*(*colonenvP_).graph2).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 11));
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T8_;
		NimStringDesc* T9_;
		T8_ = (NimStringDesc*)0;
		T8_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
		T9_ = (NimStringDesc*)0;
		T9_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 1));
		moveDir__ZIkDlvIsvzKWHk1wL9bH1lg(T8_, T9_);
	}
	LA1_: ;
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__BeJgrOdDsczOwEWOZbRfKA_))) {
			TM__FA6jNt3IW9afkuZFmR0bnUQ_28.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__jLt3ACHcgYt9bbV4Vf9a5mgwsystem());
			popCurrentException();
		}
	}
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_28.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_11)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	TSafePoint TM__FA6jNt3IW9afkuZFmR0bnUQ_30;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__FA6jNt3IW9afkuZFmR0bnUQ_30);
	TM__FA6jNt3IW9afkuZFmR0bnUQ_30.status = _setjmp(TM__FA6jNt3IW9afkuZFmR0bnUQ_30.context);
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_30.status == 0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = NIM_FALSE;
		if (T3_) goto LA4_;
		T3_ = ((*(*(*colonenvP_).graph2).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 11));
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T8_;
		NimStringDesc* T9_;
		T8_ = (NimStringDesc*)0;
		T8_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
		T9_ = (NimStringDesc*)0;
		T9_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 1));
		noscopyFile(T8_, T9_);
	}
	LA1_: ;
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__BeJgrOdDsczOwEWOZbRfKA_))) {
			TM__FA6jNt3IW9afkuZFmR0bnUQ_30.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__jLt3ACHcgYt9bbV4Vf9a5mgwsystem());
			popCurrentException();
		}
	}
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_30.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_12)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	TSafePoint TM__FA6jNt3IW9afkuZFmR0bnUQ_32;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__FA6jNt3IW9afkuZFmR0bnUQ_32);
	TM__FA6jNt3IW9afkuZFmR0bnUQ_32.status = _setjmp(TM__FA6jNt3IW9afkuZFmR0bnUQ_32.context);
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_32.status == 0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = NIM_FALSE;
		if (T3_) goto LA4_;
		T3_ = ((*(*(*colonenvP_).graph2).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 11));
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T8_;
		NimStringDesc* T9_;
		T8_ = (NimStringDesc*)0;
		T8_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
		T9_ = (NimStringDesc*)0;
		T9_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 1));
		noscopyDir(T8_, T9_);
	}
	LA1_: ;
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__BeJgrOdDsczOwEWOZbRfKA_))) {
			TM__FA6jNt3IW9afkuZFmR0bnUQ_32.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__jLt3ACHcgYt9bbV4Vf9a5mgwsystem());
			popCurrentException();
		}
	}
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_32.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_13)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	TSafePoint TM__FA6jNt3IW9afkuZFmR0bnUQ_34;
	NimStringDesc* T1_;
	tyObject_Time__3y2ZpqsTJLqdZvpC9a0rU2Q T2_;
	NI64 T3_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__FA6jNt3IW9afkuZFmR0bnUQ_34);
	TM__FA6jNt3IW9afkuZFmR0bnUQ_34.status = _setjmp(TM__FA6jNt3IW9afkuZFmR0bnUQ_34.context);
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_34.status == 0) {
	T1_ = (NimStringDesc*)0;
	T1_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
	T2_ = nosgetLastModificationTime(T1_);
	T3_ = (NI64)0;
	T3_ = toUnix__mXmxlr1pBpariZiJTjytHg(T2_);
	setResult__TT9cdDQkh09c214lMSxKXTTg(a, T3_);
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__BeJgrOdDsczOwEWOZbRfKA_))) {
			TM__FA6jNt3IW9afkuZFmR0bnUQ_34.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__jLt3ACHcgYt9bbV4Vf9a5mgwsystem());
			popCurrentException();
		}
	}
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_34.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_14)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	TSafePoint TM__FA6jNt3IW9afkuZFmR0bnUQ_36;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__FA6jNt3IW9afkuZFmR0bnUQ_36);
	TM__FA6jNt3IW9afkuZFmR0bnUQ_36.status = _setjmp(TM__FA6jNt3IW9afkuZFmR0bnUQ_36.context);
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_36.status == 0) {
	T1_ = (NimStringDesc*)0;
	T1_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
	T2_ = (NimStringDesc*)0;
	T2_ = findExe__9cov9c3aI19bfbEIyMe9bNCSEA(T1_, NIM_TRUE, ExeExts__ONrgkgAZ9bh6KVTWl4XeOSw, 1);
	setResult__g9crT9ba9c0OxETalTxR9cv1Sw(a, T2_);
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__BeJgrOdDsczOwEWOZbRfKA_))) {
			TM__FA6jNt3IW9afkuZFmR0bnUQ_36.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__jLt3ACHcgYt9bbV4Vf9a5mgwsystem());
			popCurrentException();
		}
	}
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_36.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_15)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	TSafePoint TM__FA6jNt3IW9afkuZFmR0bnUQ_38;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__FA6jNt3IW9afkuZFmR0bnUQ_38);
	TM__FA6jNt3IW9afkuZFmR0bnUQ_38.status = _setjmp(TM__FA6jNt3IW9afkuZFmR0bnUQ_38.context);
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_38.status == 0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = NIM_FALSE;
		if (T3_) goto LA4_;
		T3_ = ((*(*(*colonenvP_).graph2).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 11));
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T8_;
		NI T9_;
		T8_ = (NimStringDesc*)0;
		T8_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
		T9_ = (NI)0;
		T9_ = nospexecCmd(T8_);
		setResult__TT9cdDQkh09c214lMSxKXTTg(a, ((NI64) (T9_)));
	}
	LA1_: ;
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__BeJgrOdDsczOwEWOZbRfKA_))) {
			TM__FA6jNt3IW9afkuZFmR0bnUQ_38.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__jLt3ACHcgYt9bbV4Vf9a5mgwsystem());
			popCurrentException();
		}
	}
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_38.status != 0) reraiseException();
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a) {
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	NimStringDesc* T3_;
	T1_ = (NimStringDesc*)0;
	T1_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
	T2_ = (NimStringDesc*)0;
	T2_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 1));
	T3_ = (NimStringDesc*)0;
	T3_ = getEnv__hhED57tMl0Iaa5bOg9cJaig(T1_, T2_);
	setResult__g9crT9ba9c0OxETalTxR9cv1Sw(a, T3_);
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_2)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a) {
	NimStringDesc* T1_;
	NIM_BOOL T2_;
	T1_ = (NimStringDesc*)0;
	T1_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
	T2_ = (NIM_BOOL)0;
	T2_ = existsEnv__HhiDHRQxJ349a6FFxO51gqQ(T1_);
	setResult__X7b1uTvNjENZoIKwHxPn9aA(a, T2_);
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_3)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a) {
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	T1_ = (NimStringDesc*)0;
	T1_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
	T2_ = (NimStringDesc*)0;
	T2_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 1));
	putEnv__YVZCqlK3fKyVR367JpYgKA(T1_, T2_);
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_4)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a) {
	NimStringDesc* T1_;
	T1_ = (NimStringDesc*)0;
	T1_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
	delEnv__B4Cfq0UpEu7Wu9cYZh9cgVlw(T1_);
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_5)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a) {
	NimStringDesc* T1_;
	NIM_BOOL T2_;
	T1_ = (NimStringDesc*)0;
	T1_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
	T2_ = (NIM_BOOL)0;
	T2_ = nosdirExists(T1_);
	setResult__X7b1uTvNjENZoIKwHxPn9aA(a, T2_);
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_6)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a) {
	NimStringDesc* T1_;
	NIM_BOOL T2_;
	T1_ = (NimStringDesc*)0;
	T1_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
	T2_ = (NIM_BOOL)0;
	T2_ = nosfileExists(T1_);
	setResult__X7b1uTvNjENZoIKwHxPn9aA(a, T2_);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_16)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	setResult__g9crT9ba9c0OxETalTxR9cv1Sw(a, (*(*colonenvP_).conf3).projectName);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_17)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	setResult__g9crT9ba9c0OxETalTxR9cv1Sw(a, (*(*colonenvP_).conf3).projectPath);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_18)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	setResult__g9crT9ba9c0OxETalTxR9cv1Sw(a, (*(*colonenvP_).conf3).projectFull);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_19)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	setResult__g9crT9ba9c0OxETalTxR9cv1Sw(a, (*colonenvP_).vthisDir4);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_20)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	T1_ = (NimStringDesc*)0;
	T1_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
	T2_ = (NimStringDesc*)0;
	T2_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 1));
	setConfigVar__6QeR1iJ9b9aIgKE4A0vKaYTQ((*colonenvP_).conf3, T1_, T2_);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_21)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	T1_ = (NimStringDesc*)0;
	T1_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
	T2_ = (NimStringDesc*)0;
	T2_ = getConfigVar__nT6pi8CimjduqrsM6Cc8mQ((*colonenvP_).conf3, T1_, ((NimStringDesc*) NIM_NIL));
	setResult__g9crT9ba9c0OxETalTxR9cv1Sw(a, T2_);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_22)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	NimStringDesc* T1_;
	NIM_BOOL T2_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	T1_ = (NimStringDesc*)0;
	T1_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
	T2_ = (NIM_BOOL)0;
	T2_ = existsConfigVar__ut8y6zhxwL6n6Sz9akfQBGg((*colonenvP_).conf3, T1_);
	setResult__X7b1uTvNjENZoIKwHxPn9aA(a, T2_);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_23)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	NimStringDesc* T1_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	T1_ = (NimStringDesc*)0;
	T1_ = getNimcacheDir__oltK69akg0xLqkR2ITKbomg_2((*colonenvP_).conf3);
	setResult__g9crT9ba9c0OxETalTxR9cv1Sw(a, T1_);
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_7)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a) {
	NI64 T1_;
	NimStringDesc* T2_;
	T1_ = (NI64)0;
	T1_ = getInt__VJ5Unk9bDoOAoLiZLdhb9b1Q(a, ((NI) 0));
	T2_ = (NimStringDesc*)0;
	T2_ = paramStr__T0ST6UXXTEqaiXY9akIayng(((NI) (T1_)));
	setResult__g9crT9ba9c0OxETalTxR9cv1Sw(a, T2_);
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_8)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a) {
	NI T1_;
	T1_ = (NI)0;
	T1_ = paramCount__LYkRnwMk6UXTCs9c59cPvZsQ();
	setResult__TT9cdDQkh09c214lMSxKXTTg(a, ((NI64) (T1_)));
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_9)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a) {
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	NI T3_;
	T1_ = (NimStringDesc*)0;
	T1_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
	T2_ = (NimStringDesc*)0;
	T2_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 1));
	T3_ = (NI)0;
	T3_ = nsuCmpIgnoreStyle(T1_, T2_);
	setResult__TT9cdDQkh09c214lMSxKXTTg(a, ((NI64) (T3_)));
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_10)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a) {
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	NI T3_;
	T1_ = (NimStringDesc*)0;
	T1_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
	T2_ = (NimStringDesc*)0;
	T2_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 1));
	T3_ = (NI)0;
	T3_ = nsuCmpIgnoreCase(T1_, T2_);
	setResult__TT9cdDQkh09c214lMSxKXTTg(a, ((NI64) (T3_)));
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_24)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	NimStringDesc* arg;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	asgnRef((void**) (&(*(*colonenvP_).conf3).command), getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0)));
	arg = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 1));
	(*(*colonenvP_).conf3).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 2)) & 63);
	{
		NimStringDesc* T5_;
		NimStringDesc* path;
		TSafePoint TM__FA6jNt3IW9afkuZFmR0bnUQ_68;
		if (!(((NI) 0) < (arg ? arg->Sup.len : 0))) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T5_ = (*(*colonenvP_).conf3).projectName; (*(*colonenvP_).conf3).projectName = copyStringRC1(arg);
		if (T5_) nimGCunrefNoCycle(T5_);
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = nosisAbsolute((*(*colonenvP_).conf3).projectName);
			if (!T8_) goto LA9_;
			path = (*(*colonenvP_).conf3).projectName;
		}
		goto LA6_;
		LA9_: ;
		{
			path = slash___QVqo5OOQAdrjFqBsPctklw((*(*colonenvP_).conf3).projectPath, (*(*colonenvP_).conf3).projectName);
		}
		LA6_: ;
		pushSafePoint(&TM__FA6jNt3IW9afkuZFmR0bnUQ_68);
		TM__FA6jNt3IW9afkuZFmR0bnUQ_68.status = _setjmp(TM__FA6jNt3IW9afkuZFmR0bnUQ_68.context);
		if (TM__FA6jNt3IW9afkuZFmR0bnUQ_68.status == 0) {
		asgnRef((void**) (&(*(*colonenvP_).conf3).projectFull), canonicalizePath__9bhgFqdEZM7DoX7p3U69bQEg((*colonenvP_).conf3, path));
		popSafePoint();
		}
		else {
			popSafePoint();
			if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__BeJgrOdDsczOwEWOZbRfKA_))) {
				NimStringDesc* T14_;
				TM__FA6jNt3IW9afkuZFmR0bnUQ_68.status = 0;
				T14_ = (NimStringDesc*)0;
				T14_ = (*(*colonenvP_).conf3).projectFull; (*(*colonenvP_).conf3).projectFull = copyStringRC1(path);
				if (T14_) nimGCunrefNoCycle(T14_);
				popCurrentException();
			}
		}
		if (TM__FA6jNt3IW9afkuZFmR0bnUQ_68.status != 0) reraiseException();
	}
	LA3_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_25)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	setResult__g9crT9ba9c0OxETalTxR9cv1Sw(a, (*(*colonenvP_).conf3).command);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_26)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	T1_ = (NimStringDesc*)0;
	T1_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
	T2_ = (NimStringDesc*)0;
	T2_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 1));
	processSwitch__DS57z9bPOnpy1Lyf6Fyb2vA(T1_, T2_, ((tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA) 2), (*(*colonenvP_).module5).info, (*colonenvP_).conf3);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_27)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	T1_ = (NimStringDesc*)0;
	T1_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
	T2_ = (NimStringDesc*)0;
	T2_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 1));
	processSpecificNote__B59avMINa9cm5CFqefE9bgZIQ(T1_, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 121), ((tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA) 2), (*(*colonenvP_).module5).info, T2_, (*colonenvP_).conf3);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_28)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	T1_ = (NimStringDesc*)0;
	T1_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
	T2_ = (NimStringDesc*)0;
	T2_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 1));
	processSpecificNote__B59avMINa9cm5CFqefE9bgZIQ(T1_, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 120), ((tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA) 2), (*(*colonenvP_).module5).info, T2_, (*colonenvP_).conf3);
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__i80o3k0SgEI5gTRCzYdyWAsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_29)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	NimStringDesc* key;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	NimStringDesc* T3_;
	NimStringDesc* val;
	NimStringDesc* T4_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	T1_ = (NimStringDesc*)0;
	T2_ = (NimStringDesc*)0;
	T2_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
	T3_ = (NimStringDesc*)0;
	T3_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 1));
	T1_ = rawNewString((T2_ ? T2_->Sup.len : 0) + (T3_ ? T3_->Sup.len : 0) + 1);
appendString(T1_, T2_);
appendString(T1_, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_74));
appendString(T1_, T3_);
	key = T1_;
	T4_ = (NimStringDesc*)0;
	T4_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 2));
	val = nosaddFileExt(T4_, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_75));
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = contains__wAzSnEu9cCHHjvPQlWBZUeQ(val, TM__FA6jNt3IW9afkuZFmR0bnUQ_76);
		if (!T7_) goto LA8_;
		val = pathSubs__paMedXIWX6si307wASTsQQ((*colonenvP_).conf3, val, (*colonenvP_).vthisDir4);
	}
	goto LA5_;
	LA8_: ;
	{
		NIM_BOOL T11_;
		T11_ = (NIM_BOOL)0;
		T11_ = nosisAbsolute(val);
		if (!!(T11_)) goto LA12_;
		val = slash___gEyhbzZ1UcxyenWRLJRXNQ((*colonenvP_).vthisDir4, val);
	}
	goto LA5_;
	LA12_: ;
	LA5_: ;
	nstPut((*(*colonenvP_).conf3).moduleOverrides, key, val);
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_11)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a) {
	NimStringDesc* T1_;
	T1_ = (NimStringDesc*)0;
	T1_ = nosgetAppFilename();
	setResult__g9crT9ba9c0OxETalTxR9cv1Sw(a, T1_);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_30)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	NimStringDesc* T1_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	T1_ = (NimStringDesc*)0;
	T1_ = getString__fqypzXhNY5rpF89ak7Q0GlQ(a, ((NI) 0));
	cppDefine__3wmoYTSOyQ3GsJJ4H7J3lQ((*colonenvP_).conf3, T1_);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_31)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	TSafePoint TM__FA6jNt3IW9afkuZFmR0bnUQ_81;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__FA6jNt3IW9afkuZFmR0bnUQ_81);
	TM__FA6jNt3IW9afkuZFmR0bnUQ_81.status = _setjmp(TM__FA6jNt3IW9afkuZFmR0bnUQ_81.context);
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_81.status == 0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = NIM_FALSE;
		if (T3_) goto LA4_;
		T3_ = ((*(*(*colonenvP_).graph2).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 11));
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T8_;
		setResult__g9crT9ba9c0OxETalTxR9cv1Sw(a, ((NimStringDesc*) NIM_NIL));
		T8_ = (NimStringDesc*)0;
		T8_ = readLine__IfmAdseskhTUnfEYpOo5fA(__stdinp);
		setResult__g9crT9ba9c0OxETalTxR9cv1Sw(a, T8_);
	}
	LA1_: ;
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__KGSY1JdrNB7Xi8KDhXFhSg_))) {
			TM__FA6jNt3IW9afkuZFmR0bnUQ_81.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__jLt3ACHcgYt9bbV4Vf9a5mgwsystem());
			popCurrentException();
		}
	}
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_81.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_32)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenvP_;
	TSafePoint TM__FA6jNt3IW9afkuZFmR0bnUQ_83;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__FA6jNt3IW9afkuZFmR0bnUQ_83);
	TM__FA6jNt3IW9afkuZFmR0bnUQ_83.status = _setjmp(TM__FA6jNt3IW9afkuZFmR0bnUQ_83.context);
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_83.status == 0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = NIM_FALSE;
		if (T3_) goto LA4_;
		T3_ = ((*(*(*colonenvP_).graph2).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 11));
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T8_;
		setResult__g9crT9ba9c0OxETalTxR9cv1Sw(a, ((NimStringDesc*) NIM_NIL));
		T8_ = (NimStringDesc*)0;
		T8_ = readAll__mQf9blHFlTwuSvJjirhpY6g(__stdinp);
		setResult__g9crT9ba9c0OxETalTxR9cv1Sw(a, T8_);
	}
	LA1_: ;
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__KGSY1JdrNB7Xi8KDhXFhSg_))) {
			TM__FA6jNt3IW9afkuZFmR0bnUQ_83.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__jLt3ACHcgYt9bbV4Vf9a5mgwsystem());
			popCurrentException();
		}
	}
	if (TM__FA6jNt3IW9afkuZFmR0bnUQ_83.status != 0) reraiseException();
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw*, setupVM__ykATGWoPQlrTWSpzeaqsuA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, NimStringDesc* scriptName, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph) {
	tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw* result;
	tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw* colonenv_;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T1_;
	NimStringDesc* T2_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T3_;
	NI T4_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T5_;
	NI T6_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T7_;
	NI T8_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T9_;
	NI T10_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T11_;
	NI T12_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T13_;
	NI T14_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T15_;
	NI T16_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T17_;
	NI T18_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T19_;
	NI T20_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T21_;
	NI T22_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T23_;
	NI T24_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T25_;
	NI T26_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T27_;
	NI T28_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T29_;
	NI T30_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T31_;
	NI T32_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T33_;
	NI T34_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T35_;
	NI T36_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T37_;
	NI T38_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T39_;
	NI T40_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T41_;
	NI T42_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T43_;
	NI T44_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T45_;
	NI T46_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T47_;
	NI T48_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T49_;
	NI T50_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T51_;
	NI T52_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T53_;
	NI T54_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T55_;
	NI T56_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T57_;
	NI T58_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T59_;
	NI T60_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T61_;
	NI T62_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T63_;
	NI T64_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T65_;
	NI T66_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T67_;
	NI T68_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T69_;
	NI T70_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T71_;
	NI T72_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T73_;
	NI T74_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T75_;
	NI T76_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T77_;
	NI T78_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T79_;
	NI T80_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T81_;
	NI T82_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T83_;
	NI T84_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T85_;
	NI T86_;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T87_;
	NI T88_;
	result = (tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw*)0;
	colonenv_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*)0;
	colonenv_ = (tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*) newObj((&NTI__09cLp9cIksPJn1aayfzodABg_), sizeof(tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw));
	(*colonenv_).Sup.m_type = (&NTI__OuG3LnpRCpfRkLDW5KdmIw_);
	asgnRef((void**) (&(*colonenv_).module5), module);
	asgnRef((void**) (&(*colonenv_).graph2), graph);
	result = newCtx__SnMRNFK9aeDXTXGWpZkzETw((*colonenv_).module5, cache, (*colonenv_).graph2);
	(*result).mode = ((tyEnum_TEvalMode__UbrbHUpo4hYFr1DbYzJgRQ) 0);
	registerAdditionalOps__YCoJV0XHfn0P9cfljlakO1g(result);
	asgnRef((void**) (&(*colonenv_).conf3), (*(*colonenv_).graph2).config);
	(*colonenv_).errorMsg1 = (NimStringDesc*)0;
	nimZeroMem((void*)(&T1_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	nossplitFile(scriptName, (&T1_));
	T2_ = (NimStringDesc*)0;
	T2_ = (*colonenv_).vthisDir4; (*colonenv_).vthisDir4 = copyStringRC1(T1_.Field0);
	if (T2_) nimGCunrefNoCycle(T2_);
	nimZeroMem((void*)(&T3_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T3_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA; T3_.ClE_0 = colonenv_;
	T4_ = (NI)0;
	T4_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_7), T3_);
	nimZeroMem((void*)(&T5_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T5_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_2; T5_.ClE_0 = colonenv_;
	T6_ = (NI)0;
	T6_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_12), T5_);
	nimZeroMem((void*)(&T7_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T7_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_3; T7_.ClE_0 = colonenv_;
	T8_ = (NI)0;
	T8_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_14), T7_);
	nimZeroMem((void*)(&T9_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T9_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_4; T9_.ClE_0 = colonenv_;
	T10_ = (NI)0;
	T10_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_16), T9_);
	nimZeroMem((void*)(&T11_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T11_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_5; T11_.ClE_0 = colonenv_;
	T12_ = (NI)0;
	T12_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_18), T11_);
	nimZeroMem((void*)(&T13_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T13_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_6; T13_.ClE_0 = colonenv_;
	T14_ = (NI)0;
	T14_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_20), T13_);
	nimZeroMem((void*)(&T15_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T15_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_7; T15_.ClE_0 = colonenv_;
	T16_ = (NI)0;
	T16_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_21), T15_);
	nimZeroMem((void*)(&T17_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T17_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_8; T17_.ClE_0 = colonenv_;
	T18_ = (NI)0;
	T18_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_23), T17_);
	nimZeroMem((void*)(&T19_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T19_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_9; T19_.ClE_0 = colonenv_;
	T20_ = (NI)0;
	T20_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_25), T19_);
	nimZeroMem((void*)(&T21_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T21_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_10; T21_.ClE_0 = colonenv_;
	T22_ = (NI)0;
	T22_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_27), T21_);
	nimZeroMem((void*)(&T23_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T23_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_11; T23_.ClE_0 = colonenv_;
	T24_ = (NI)0;
	T24_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_29), T23_);
	nimZeroMem((void*)(&T25_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T25_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_12; T25_.ClE_0 = colonenv_;
	T26_ = (NI)0;
	T26_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_31), T25_);
	nimZeroMem((void*)(&T27_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T27_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_13; T27_.ClE_0 = colonenv_;
	T28_ = (NI)0;
	T28_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_33), T27_);
	nimZeroMem((void*)(&T29_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T29_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_14; T29_.ClE_0 = colonenv_;
	T30_ = (NI)0;
	T30_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_35), T29_);
	nimZeroMem((void*)(&T31_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T31_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_15; T31_.ClE_0 = colonenv_;
	T32_ = (NI)0;
	T32_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_37), T31_);
	nimZeroMem((void*)(&T33_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T33_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_40) (colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ)); T33_.ClE_0 = NIM_NIL;
	T34_ = (NI)0;
	T34_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_39), T33_);
	nimZeroMem((void*)(&T35_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T35_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_42) (colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_2)); T35_.ClE_0 = NIM_NIL;
	T36_ = (NI)0;
	T36_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_41), T35_);
	nimZeroMem((void*)(&T37_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T37_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_44) (colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_3)); T37_.ClE_0 = NIM_NIL;
	T38_ = (NI)0;
	T38_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_43), T37_);
	nimZeroMem((void*)(&T39_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T39_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_46) (colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_4)); T39_.ClE_0 = NIM_NIL;
	T40_ = (NI)0;
	T40_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_45), T39_);
	nimZeroMem((void*)(&T41_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T41_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_48) (colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_5)); T41_.ClE_0 = NIM_NIL;
	T42_ = (NI)0;
	T42_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_47), T41_);
	nimZeroMem((void*)(&T43_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T43_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_50) (colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_6)); T43_.ClE_0 = NIM_NIL;
	T44_ = (NI)0;
	T44_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_49), T43_);
	nimZeroMem((void*)(&T45_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T45_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_16; T45_.ClE_0 = colonenv_;
	T46_ = (NI)0;
	T46_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_51), T45_);
	nimZeroMem((void*)(&T47_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T47_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_17; T47_.ClE_0 = colonenv_;
	T48_ = (NI)0;
	T48_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_52), T47_);
	nimZeroMem((void*)(&T49_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T49_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_18; T49_.ClE_0 = colonenv_;
	T50_ = (NI)0;
	T50_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_53), T49_);
	nimZeroMem((void*)(&T51_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T51_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_19; T51_.ClE_0 = colonenv_;
	T52_ = (NI)0;
	T52_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_54), T51_);
	nimZeroMem((void*)(&T53_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T53_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_20; T53_.ClE_0 = colonenv_;
	T54_ = (NI)0;
	T54_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_55), T53_);
	nimZeroMem((void*)(&T55_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T55_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_21; T55_.ClE_0 = colonenv_;
	T56_ = (NI)0;
	T56_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_56), T55_);
	nimZeroMem((void*)(&T57_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T57_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_22; T57_.ClE_0 = colonenv_;
	T58_ = (NI)0;
	T58_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_57), T57_);
	nimZeroMem((void*)(&T59_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T59_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_23; T59_.ClE_0 = colonenv_;
	T60_ = (NI)0;
	T60_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_58), T59_);
	nimZeroMem((void*)(&T61_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T61_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_60) (colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_7)); T61_.ClE_0 = NIM_NIL;
	T62_ = (NI)0;
	T62_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_59), T61_);
	nimZeroMem((void*)(&T63_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T63_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_62) (colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_8)); T63_.ClE_0 = NIM_NIL;
	T64_ = (NI)0;
	T64_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_61), T63_);
	nimZeroMem((void*)(&T65_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T65_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_64) (colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_9)); T65_.ClE_0 = NIM_NIL;
	T66_ = (NI)0;
	T66_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_63), T65_);
	nimZeroMem((void*)(&T67_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T67_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_66) (colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_10)); T67_.ClE_0 = NIM_NIL;
	T68_ = (NI)0;
	T68_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_65), T67_);
	nimZeroMem((void*)(&T69_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T69_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_24; T69_.ClE_0 = colonenv_;
	T70_ = (NI)0;
	T70_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_67), T69_);
	nimZeroMem((void*)(&T71_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T71_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_25; T71_.ClE_0 = colonenv_;
	T72_ = (NI)0;
	T72_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_69), T71_);
	nimZeroMem((void*)(&T73_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T73_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_26; T73_.ClE_0 = colonenv_;
	T74_ = (NI)0;
	T74_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_70), T73_);
	nimZeroMem((void*)(&T75_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T75_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_27; T75_.ClE_0 = colonenv_;
	T76_ = (NI)0;
	T76_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_71), T75_);
	nimZeroMem((void*)(&T77_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T77_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_28; T77_.ClE_0 = colonenv_;
	T78_ = (NI)0;
	T78_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_72), T77_);
	nimZeroMem((void*)(&T79_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T79_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_29; T79_.ClE_0 = colonenv_;
	T80_ = (NI)0;
	T80_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_73), T79_);
	nimZeroMem((void*)(&T81_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T81_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_78) (colonanonymous___mI15Hgrozxi9bgw7wG8HEOQ_11)); T81_.ClE_0 = NIM_NIL;
	T82_ = (NI)0;
	T82_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_77), T81_);
	nimZeroMem((void*)(&T83_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T83_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_30; T83_.ClE_0 = colonenv_;
	T84_ = (NI)0;
	T84_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_79), T83_);
	nimZeroMem((void*)(&T85_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T85_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_31; T85_.ClE_0 = colonenv_;
	T86_ = (NI)0;
	T86_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_80), T85_);
	nimZeroMem((void*)(&T87_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T87_.ClP_0 = colonanonymous___Qr05nmgTF9aNCrBbBhUhmgA_32; T87_.ClE_0 = colonenv_;
	T88_ = (NI)0;
	T88_ = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(result, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_82), T87_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, runNimScript__9aK66nKYiNl2TBdU36GDs9aA)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, NimStringDesc* scriptName, NIM_BOOL freshDefines, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ oldSymbolFiles;
	tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph;
	tyTuple__euPCXX9bc3XzndEhYlqNS7g T5_;
	tyTuple__euPCXX9bc3XzndEhYlqNS7g T6_;
	NI T7_;
	NimStringDesc* T8_;
	tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw oldGlobalOptions;
	tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw oldSelectedGC;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m;
	tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw* T9_;
	tyObject_TLLStream__a5oZYQ9aTktYME2449ayEi6g* T10_;
	NIM_BOOL T11_;
	oldSymbolFiles = (*conf).symbolFiles;
	(*conf).symbolFiles = ((tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ) 0);
	graph = newModuleGraph__i9b4NK8jPhAUAsvbtMitNLw(cache, conf);
	connectCallbacks__bgKSaiGTRW4vbGh2XuGqSw(graph);
	{
		if (!freshDefines) goto LA3_;
		initDefines__hODM2As3BZvC4AAFuVvWwQ((*conf).symbols);
	}
	LA3_: ;
	defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_2), ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_3));
	defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_4), ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_3));
	T5_.Field0 = myOpen__aOG8hV039bfSL2VAm1lrf0Q;
	T5_.Field1 = myProcess__QAJdPOwMq9buTNGNGQO3ImA;
	T5_.Field2 = myClose__q2jGmbBjsPumxfsrswciWg;
	T5_.Field3 = NIM_TRUE;
	registerPass__VbG3eW9b2jtFMJI9bafKW9aRw(graph, (&T5_));
	T6_.Field0 = myOpen__4vajIPhcf9a5bJvp6m9ciz6A;
	T6_.Field1 = myProcess__Owg2e1qJ9cqcKRBQZVvmIWg;
	T6_.Field2 = myClose__9cMiASXBM9bgOmq0622U8U0g;
	T6_.Field3 = NIM_FALSE;
	registerPass__VbG3eW9b2jtFMJI9bafKW9aRw(graph, (&T6_));
	asgnRef((void**) (&(*conf).searchPaths), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).searchPaths), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_)));
	T7_ = (*conf).searchPaths->Sup.len++;
	T8_ = (NimStringDesc*)0;
	T8_ = (*conf).searchPaths->data[T7_]; (*conf).searchPaths->data[T7_] = copyStringRC1((*conf).libpath);
	if (T8_) nimGCunrefNoCycle(T8_);
	oldGlobalOptions = (*conf).globalOptions;
	oldSelectedGC = (*conf).selectedGC;
	undefSymbol__7r39cyzHGkKGsFt9bPVES2hQ((*conf).symbols, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_5));
	(*conf).globalOptions = ((*conf).globalOptions & ~ IL64(7696581394432));
	(*conf).selectedGC = ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 0);
	m = makeModule__X0YNzSZYcyX9cz31YOsPZuA(graph, scriptName);
	(*m).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14)) & 63);
	T9_ = (tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw*)0;
	T9_ = setupVM__ykATGWoPQlrTWSpzeaqsuA(m, cache, scriptName, graph);
	asgnRef((void**) (&(*graph).vm), &T9_->Sup.Sup);
	compileSystemModule__bgKSaiGTRW4vbGh2XuGqSw_2(graph);
	T10_ = (tyObject_TLLStream__a5oZYQ9aTktYME2449ayEi6g*)0;
	T10_ = llStreamOpen__knWUQJsEzojha6AJCi6LcA(scriptName, ((tyEnum_FileMode__ZJfK20XeZ9bv2j1pZjw9aswg) 0));
	T11_ = (NIM_BOOL)0;
	T11_ = processModule__zPTa50e0M05UK8aJ9bS48aw(graph, m, T10_);
	(void)(T11_);
	{
		if (!((*conf).selectedGC == ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 0))) goto LA14_;
		(*conf).selectedGC = oldSelectedGC;
	}
	LA14_: ;
	{
		if (!((oldGlobalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 42))&63U)))!=0)) goto LA18_;
		(*conf).globalOptions = ((*conf).globalOptions | IL64(7696581394432));
		defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_5), ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_3));
	}
	LA18_: ;
	{
		if (!((48 &((NU16)1<<((NU)((*conf).selectedGC)&15U)))!=0)) goto LA22_;
		(*conf).globalOptions = ((*conf).globalOptions | IL64(3298534883328));
		defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_5), ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_3));
	}
	LA22_: ;
	resetSystemArtifacts__qtJqiNk9aIOJrZ429bKn9aGZw(graph);
	undefSymbol__7r39cyzHGkKGsFt9bPVES2hQ((*conf).symbols, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_2));
	undefSymbol__7r39cyzHGkKGsFt9bPVES2hQ((*conf).symbols, ((NimStringDesc*) &TM__FA6jNt3IW9afkuZFmR0bnUQ_4));
	(*conf).symbolFiles = oldSymbolFiles;
}
N_LIB_PRIVATE N_NIMCALL(void, compiler_scriptconfigDatInit000)(void) {

/* section: NIM_merge_TYPE_INIT1 */
static TNimNode* TM__FA6jNt3IW9afkuZFmR0bnUQ_6_6[6];
static TNimNode TM__FA6jNt3IW9afkuZFmR0bnUQ_0[7];

/* section: NIM_merge_TYPE_INIT3 */
NTI__OuG3LnpRCpfRkLDW5KdmIw_.size = sizeof(tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw);
NTI__OuG3LnpRCpfRkLDW5KdmIw_.align = NIM_ALIGNOF(tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw);
NTI__OuG3LnpRCpfRkLDW5KdmIw_.kind = 17;
NTI__OuG3LnpRCpfRkLDW5KdmIw_.base = (&NTI__ytyiCJqK439aF9cIibuRVpAg_);
TM__FA6jNt3IW9afkuZFmR0bnUQ_6_6[0] = &TM__FA6jNt3IW9afkuZFmR0bnUQ_0[1];
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[1].kind = 1;
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[1].offset = offsetof(tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw, colonstate_);
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[1].typ = (&NTI__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[1].name = ":state";
TM__FA6jNt3IW9afkuZFmR0bnUQ_6_6[1] = &TM__FA6jNt3IW9afkuZFmR0bnUQ_0[2];
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[2].kind = 1;
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[2].offset = offsetof(tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw, errorMsg1);
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[2].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[2].name = "errorMsg1";
TM__FA6jNt3IW9afkuZFmR0bnUQ_6_6[2] = &TM__FA6jNt3IW9afkuZFmR0bnUQ_0[3];
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[3].kind = 1;
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[3].offset = offsetof(tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw, graph2);
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[3].typ = (&NTI__KfdHSsl8vyUCSI9b3inBcww_);
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[3].name = "graph2";
TM__FA6jNt3IW9afkuZFmR0bnUQ_6_6[3] = &TM__FA6jNt3IW9afkuZFmR0bnUQ_0[4];
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[4].kind = 1;
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[4].offset = offsetof(tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw, conf3);
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[4].typ = (&NTI__a8lycfSA25OQltN3OMeBsA_);
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[4].name = "conf3";
TM__FA6jNt3IW9afkuZFmR0bnUQ_6_6[4] = &TM__FA6jNt3IW9afkuZFmR0bnUQ_0[5];
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[5].kind = 1;
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[5].offset = offsetof(tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw, vthisDir4);
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[5].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[5].name = "vthisDir4";
TM__FA6jNt3IW9afkuZFmR0bnUQ_6_6[5] = &TM__FA6jNt3IW9afkuZFmR0bnUQ_0[6];
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[6].kind = 1;
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[6].offset = offsetof(tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw, module5);
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[6].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[6].name = "module5";
TM__FA6jNt3IW9afkuZFmR0bnUQ_0[0].len = 6; TM__FA6jNt3IW9afkuZFmR0bnUQ_0[0].kind = 2; TM__FA6jNt3IW9afkuZFmR0bnUQ_0[0].sons = &TM__FA6jNt3IW9afkuZFmR0bnUQ_6_6[0];
NTI__OuG3LnpRCpfRkLDW5KdmIw_.node = &TM__FA6jNt3IW9afkuZFmR0bnUQ_0[0];
NTI__09cLp9cIksPJn1aayfzodABg_.size = sizeof(tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*);
NTI__09cLp9cIksPJn1aayfzodABg_.align = NIM_ALIGNOF(tyObject_Env_scriptconfigdotnim_setupVM___OuG3LnpRCpfRkLDW5KdmIw*);
NTI__09cLp9cIksPJn1aayfzodABg_.kind = 22;
NTI__09cLp9cIksPJn1aayfzodABg_.base = (&NTI__OuG3LnpRCpfRkLDW5KdmIw_);
NTI__09cLp9cIksPJn1aayfzodABg_.marker = Marker_tyRef__09cLp9cIksPJn1aayfzodABg;
}

